@@ -1,6 +1,6 @@
 from ._base import TableMixin
 
-__all__ = ['HRTEMP', 'HRTCPR', 'PRTMST', 'PRTECNEM']
+__all__ = ['HRTEMP', 'HRTCPR', 'PRTMST', 'PRTECN']
 
 import datetime
 
@@ -246,21 +246,23 @@ class PRTMST(TableMixin):
     SUFFIX = ('CHAR', 18)
     SUPERVISOR1 = ('CHAR', 18)
 
-class PRTECNEM(TableMixin):
+class PRTECN(TableMixin):
 
-    TABLE_NAME = 'PRTECNEM'
+    TABLE_NAME = 'PRTECN'
+
+    PRTECNID = ('INT', 18)
+    PRTMSTID = ('INT', 18)
+    STATUSCODE = ('CHAR', 1)
+    COMPANYNO = ('DEC', 2)
+    DIVISIONNO = ('DEC', 3)
+    EMPLOYEENO = ('INT', 9)
+    SEQNO = ('DEC', 2)
+    CONTNAME = ('CHAR', 30)
+    CELLPHAC = ('DEC', 3)
+    CELLPHNO = ('DEC', 7)
+    FAXAC = ('DEC', 3)
+    FAXPHNO = ('DEC', 7)
+    OTHAC = ('DEC', 3)
+    OTHPHNO = ('DEC', 7)
+    EMAILADDR = ('CHAR', 64)
 
-    PRTECNEMID = ('INT', 18)
-    COMPANYNUMBER = ('DEC', 2)
-    DIVISIONNUMBER = ('DEC', 3)
-    EMPLOYEENUMBER = ('INT', 9)
-    SEQUENCENUMBER = ('DEC', 2)
-    EMAILADDRESS = ('CHAR', 64)
-    TYPE1 = ('CHAR', 1)
-    TYPE2 = ('CHAR', 1)
-    TYPE3 = ('CHAR', 1)
-    TYPE4 = ('CHAR', 1)
-    TYPE5 = ('CHAR', 1)
-    TYPE6 = ('CHAR', 1)
-    USERID = ('CHAR', 10)
-    UPDPROGRAM = ('CHAR', 25)
